PostgrestClient class
A PostgREST api client written in Dartlang. The goal of this library is to make an "ORM-like" restful interface.
Constructors
-
PostgrestClient(String url, {Map<
String, String> ? headers, String? schema, Client? httpClient, YAJsonIsolate? isolate, bool retryEnabled = true, @visibleForTesting Duration retryDelay(int attempt)?}) -
To create a PostgrestClient, you need to provide an
urlendpoint.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
- httpClient → Client?
-
final
- retryEnabled → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
auth(
String token) → PostgrestClient - Authenticates the request with JWT.
-
dispose(
) → Future< void> -
from(
String table) → PostgrestQueryBuilder< void> - Perform a table operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rpc<
T> (String fn, {Map? params, bool get = false}) → PostgrestFilterBuilder< T> - Performs a stored procedure call.
-
schema(
String schema) → PostgrestClient - Select a schema to query or perform an function (rpc) call.
-
setAuth(
String? token) → PostgrestClient -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited