RealtimeSystemPayload class

Payload of a system event emitted by the server.

Most notably, when a channel is created with RealtimeChannelConfig.replicationReady set to true, the server sends one of these once the Postgres replication connection is ready (status is 'ok') or fails to become ready in time (status is 'error').

Constructors

RealtimeSystemPayload({required String extension, required String status, required String message, required String channel})
const
RealtimeSystemPayload.fromJson(Map<String, dynamic> json)
factory

Properties

channel String
The channel (sub)topic the message refers to.
final
extension String
The extension that produced the message, e.g. 'system' or 'postgres_changes'.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description, e.g. 'Replication connection established'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
'ok' on success, 'error' on failure.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited